@@ -121,7 +121,7 @@ public:
                                 int itemCount,
                                 bool isSelected);
 
-    AgendaItem::QPtr insertAllDayItem(const KCalendarCore::Incidence::Ptr &event, const QDateTime &recurrenceId, int XBegin, int XEnd, bool isSelected);
+    AgendaItem::QPtr insertAllDayItem(const KCalendarCore::Incidence::Ptr &incidence, const QDateTime &recurrenceId, int XBegin, int XEnd, bool isSelected);
 
     void
     insertMultiItem(const KCalendarCore::Incidence::Ptr &event, const QDateTime &recurrenceId, int XBegin, int XEnd, int YTop, int YBottom, bool isSelected);
@@ -175,7 +175,7 @@ public Q_SLOTS:
       deselected. This function emits the itemSelected(bool) signal to inform
       about selection/deselection of events.
     */
-    void selectItem(const AgendaItem::QPtr &);
+    void selectItem(const EventViews::AgendaItem::QPtr &);
 
     /**
       Selects the item associated with a given Akonadi Item id.
@@ -186,8 +186,8 @@ public Q_SLOTS:
     void selectIncidenceByUid(const QString &id);
     void selectItem(const Akonadi::Item &item);
 
-    bool removeAgendaItem(const AgendaItem::QPtr &item);
-    void showAgendaItem(const AgendaItem::QPtr &item);
+    bool removeAgendaItem(const EventViews::AgendaItem::QPtr &item);
+    void showAgendaItem(const EventViews::AgendaItem::QPtr &item);
 
 Q_SIGNALS:
     void newEventSignal();
@@ -207,8 +207,8 @@ Q_SIGNALS:
     void upperYChanged(int);
 
     void startDragSignal(const KCalendarCore::Incidence::Ptr &);
-    void droppedIncidences(const KCalendarCore::Incidence::List &, const QPoint &gpos, bool allDay);
-    void droppedIncidences(const QList<QUrl> &, const QPoint &gpos, bool allDay);
+    void droppedIncidencesSignal(const KCalendarCore::Incidence::List &, const QPoint &gpos, bool allDay);
+    void droppedUrlsSignal(const QList<QUrl> &, const QPoint &gpos, bool allDay);
 
     void enableAgendaUpdate(bool enable);
     void zoomView(const int delta, const QPoint &pos, const Qt::Orientation);
@@ -231,7 +231,7 @@ private:
     };
 
     AgendaItem::QPtr
-    createAgendaItem(const KCalendarCore::Incidence::Ptr &incidence, int itemPos, int itemCount, const QDateTime &recurrentId, bool isSelected);
+    createAgendaItem(const KCalendarCore::Incidence::Ptr &incidence, int itemPos, int itemCount, const QDateTime &recurrenceId, bool isSelected);
 
 protected:
     /**
