@@ -200,7 +200,7 @@ public:
 
     [[nodiscard]] QDate occurrenceDate() const;
 
-    // /** Update the date of this item's occurrence (not in the event) */
+    /** Update the date of this item's occurrence (not in the event) */
     void setOccurrenceDateTime(const QDateTime &qd);
 
     void setText(const QString &text)
@@ -233,8 +233,8 @@ public:
     }
 
 Q_SIGNALS:
-    void removeAgendaItem(const AgendaItem::QPtr &);
-    void showAgendaItem(const AgendaItem::QPtr &);
+    void removeAgendaItem(const EventViews::AgendaItem::QPtr &);
+    void showAgendaItem(const EventViews::AgendaItem::QPtr &);
 
 public Q_SLOTS:
     void updateIcons();
