@@ -9,6 +9,7 @@
 using namespace Qt::Literals::StringLiterals;
 
 #include "agenda.h"
+#include "agendaview.h"
 #include "prefs.h"
 #include "timelabelszone.h"
 #include "timescaleconfigdialog.h"
@@ -215,9 +216,9 @@ void TimeLabels::paintEvent(QPaintEvent *)
     if (!mAgenda) {
         return;
     }
-    const KCalendarCore::DateList datelist = mAgenda->dateList();
+    KCalendarCore::DateList datelist = mAgenda->dateList();
     if (datelist.isEmpty()) {
-        return;
+        datelist << mTimeLabelsZone->agendaView()->startDate();
     }
 
     QPainter p(this);
