@@ -25,6 +25,7 @@
 #include <KConfigGroup>
 
 #include "calendarview_debug.h"
+
 #include <QBoxLayout>
 #include <QHeaderView>
 #include <QIcon>
@@ -43,8 +44,8 @@ enum {
     Dummy_EOF_Column // Dummy enum value for iteration purposes only. Always keep at the end.
 };
 
-static const QTime DAY_START{00, 00};
-static const QTime DAY_END{23, 59, 59, 999};
+#define DAY_START (QTime(0, 0))
+#define DAY_END (QTime(23, 59, 59, 999))
 
 static QString cleanSummary(const QString &summary, const QDateTime &next)
 {
@@ -113,7 +114,7 @@ public:
 
     ~ListViewPrivate() = default;
 
-    void addIncidences(const Akonadi::CollectionCalendar::Ptr &calendar, const KCalendarCore::Incidence::List &incidenceList, QDate date);
+    void addIncidences(const Akonadi::CollectionCalendar::Ptr &calendar, const KCalendarCore::Incidence::List &incidences, QDate date);
     void addIncidence(const Akonadi::CollectionCalendar::Ptr &calendar, const KCalendarCore::Incidence::Ptr &, QDate date);
     void addIncidence(const Akonadi::CollectionCalendar::Ptr &calendar, const Akonadi::Item &, QDate date);
     ListViewItem *getItemForIncidence(const Akonadi::Item &);
@@ -129,7 +130,7 @@ public:
     Qt::SortOrder mSortOrder = Qt::AscendingOrder;
 
     // if it's non interactive we disable context menu, and incidence editing
-    bool mIsNonInteractive;
+    bool mIsNonInteractive = false;
     class ListItemVisitor;
 };
 
@@ -339,7 +340,7 @@ DateList ListView::selectedIncidenceDates() const
 
 void ListView::updateView()
 {
-    static int maxLen = 38;
+    static int const maxLen = 38;
 
     /* Set the width of the summary column to show 'maxlen' chars, at most */
     int width = qMin(maxLen * fontMetrics().averageCharWidth(), maxLen * 12);
@@ -366,8 +367,9 @@ void ListView::showDates(const QDate &start, const QDate &end, const QDate &pref
     d->mTreeWidget->headerItem()->setText(Summary_Column, i18n("Summary [%1 - %2]", startStr, endStr));
 
     QDate date = start;
+    const auto cals = calendars();
     while (date <= end) {
-        for (const auto &calendar : calendars()) {
+        for (const auto &calendar : cals) {
             d->addIncidences(calendar, calendar->incidences(date), date);
         }
         d->mSelectedDates.append(date);
@@ -381,7 +383,8 @@ void ListView::showDates(const QDate &start, const QDate &end, const QDate &pref
 
 void ListView::showAll()
 {
-    for (const auto &calendar : calendars()) {
+    const auto cals = calendars();
+    for (const auto &calendar : cals) {
         d->addIncidences(calendar, calendar->incidences(), QDate());
     }
 }
@@ -407,7 +410,7 @@ void ListViewPrivate::addIncidence(const Akonadi::CollectionCalendar::Ptr &calen
         return;
     }
 
-    Akonadi::Item aitem = calendar->item(incidence);
+    Akonadi::Item const aitem = calendar->item(incidence);
 
     if (!aitem.isValid() || mItems.contains(aitem.id())) {
         return;
@@ -437,10 +440,10 @@ void ListViewPrivate::addIncidence(const Akonadi::CollectionCalendar::Ptr &calen
     item->setData(0, Qt::UserRole, QVariant(aitem.id()));
 }
 
-void ListView::showIncidences(const Akonadi::Item::List &itemList, const QDate &date)
+void ListView::showIncidences(const Akonadi::Item::List &items, const QDate &date)
 {
     clear();
-    for (const auto &item : itemList) {
+    for (const auto &item : items) {
         const auto calendar = calendar3(item);
         if (calendar) {
             d->addIncidence(calendar, Akonadi::CalendarUtils::incidence(item), date);
@@ -519,7 +522,7 @@ void ListView::defaultItemAction(const QModelIndex &index)
     if (!d->mIsNonInteractive) {
         // Get the first column, it has our Akonadi::Id
         const QModelIndex col0Idx = d->mTreeWidget->model()->index(index.row(), 0);
-        Akonadi::Item::Id id = d->mTreeWidget->model()->data(col0Idx, Qt::UserRole).toLongLong();
+        Akonadi::Item::Id const id = d->mTreeWidget->model()->data(col0Idx, Qt::UserRole).toLongLong();
         defaultAction(d->mItems.value(id));
     }
 }
@@ -549,7 +552,7 @@ void ListView::popupMenu(const QPoint &point)
 
 void ListView::readSettings(KConfig *config)
 {
-    KConfigGroup cfgGroup = config->group(QStringLiteral("ListView Layout"));
+    KConfigGroup const cfgGroup = config->group(QStringLiteral("ListView Layout"));
     readSettings(cfgGroup);
 }
 
@@ -563,7 +566,7 @@ void EventViews::ListView::readSettings(const KConfigGroup &cfgGroup)
 
 void ListView::writeSettings(KConfig *config)
 {
-    KConfigGroup cfgGroup = config->group(QStringLiteral("ListView Layout"));
+    KConfigGroup const cfgGroup = config->group(QStringLiteral("ListView Layout"));
 }
 
 void EventViews::ListView::writeSettings(KConfigGroup &cfgGroup)
