@@ -27,7 +27,9 @@ ScrollIndicator::ScrollIndicator(ScrollIndicator::ArrowDirection dir)
 
 QRectF ScrollIndicator::boundingRect() const
 {
+    // NOLINTBEGIN(bugprone-integer-division)
     return {-mWidth / 2, -mHeight / 2, mWidth, mHeight};
+    // NOLINTEND(bugprone-integer-division)
 }
 
 void ScrollIndicator::paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget)
@@ -101,7 +103,7 @@ void MonthCell::addMonthItem(MonthItem *manager, int height)
 
 int MonthCell::firstFreeSpace()
 {
-    MonthItem *manager = nullptr;
+    const MonthItem *manager = nullptr;
     int i = 0;
     while (true) {
         manager = mHeightHash[i];
@@ -214,17 +216,17 @@ void MonthGraphicsItem::paint(QPainter *p, const QStyleOptionGraphicsItem *, QWi
 
     MonthScene *scene = mMonthItem->monthScene();
 
-    int textMargin = 7;
+    int const textMargin = 7;
 
     QColor bgColor = mMonthItem->bgColor();
     bgColor = mMonthItem->selected() ? bgColor.lighter(EventView::BRIGHTNESS_FACTOR) : bgColor;
     QColor frameColor = mMonthItem->frameColor();
     frameColor = mMonthItem->selected() ? frameColor.lighter(EventView::BRIGHTNESS_FACTOR) : frameColor;
-    QColor textColor = EventViews::getTextColor(bgColor);
+    QColor const textColor = EventViews::getTextColor(bgColor);
 
     // make moving or resizing items translucent
     if (mMonthItem->isMoving() || mMonthItem->isResizing()) {
-        bgColor.setAlphaF(0.75f);
+        bgColor.setAlphaF(0.75F);
     }
 
     // draw the widget without border
@@ -293,7 +295,7 @@ void MonthGraphicsItem::paint(QPainter *p, const QStyleOptionGraphicsItem *, QWi
         textRect.setLeft(curXPos + iconWidths);
 
         // assume that all pixmaps have the same height
-        int pixYPos = icons.isEmpty() ? 0 : (textRect.height() - icons.at(0).height()) / 2;
+        int const pixYPos = icons.isEmpty() ? 0 : (textRect.height() - icons.at(0).height()) / 2;
         for (const QPixmap &icon : std::as_const(icons)) {
             p->drawPixmap(curXPos, pixYPos, icon);
             curXPos += icon.width();
@@ -346,7 +348,7 @@ void MonthGraphicsItem::updateGeometry()
 
     prepareGeometryChange();
 
-    int beginX = 1 + mMonthItem->monthScene()->cellHorizontalPos(cell);
+    int const beginX = 1 + mMonthItem->monthScene()->cellHorizontalPos(cell);
     int beginY = 1 + cell->topMargin() + mMonthItem->monthScene()->cellVerticalPos(cell);
 
     beginY += mMonthItem->position() * mMonthItem->monthScene()->itemHeightIncludingSpacing()
