@@ -106,6 +106,10 @@ private:
 
     ScrollIndicator *mUpArrow = nullptr;
     ScrollIndicator *mDownArrow = nullptr;
+
+    // disable copy ctor
+    MonthCell(const MonthCell &) = delete;
+    MonthCell &operator=(const MonthCell &) = delete;
 };
 
 /**
